package Alien::libswe;
 
use strict;
use warnings;
use parent 'Alien::Base';


=head1 NAME

Alien::libswe - Build and install Swiss Ephemeris shared library

=cut

our $VERSION = "0.007";

=head1 SYNOPSIS

Build and install Swiss Ephemeris shared library

=head1 DESCRIPTION 

See L<Alien::Build::Manual::AlienUser>

Build and install Swiss Ephemeris shared library

=head1 AUTHOR

Mike Baas <mbaas at cpan.org>

=head1 REPOSITORY

L<https://github.com/initself/Alien-libswe>

=head1 COPYRIGHT & LICENSE

This is free software; you can redistribute it and/or modify it under the same terms as the Perl 5 programming language system itself.

=cut

 
1;

